@@ -1,4 +1,4 @@
-import html,pymysql,sys,os,re,socket
+import html,pymysql,sys,os,re,socket,random
 from werkzeug.utils import secure_filename
 from werkzeug.datastructures import ImmutableMultiDict
 
@@ -123,13 +123,19 @@ class FILE_UPLOAD:
         return FILE_UPLOAD.valid_extension(FILE_UPLOAD.secure_filename(f),extentions) and FILE_UPLOAD.valid_mimetype(f,mimetypes)
 
     @staticmethod
-    def secure_filename(f):
-        return secure_filename(".".join(f.filename.split(".")[:2]))
+    def secure_filename(f,random_ids=True):
+        name= secure_filename(".".join(f.filename.split(".")[:2]))
+        if random_ids==True:
+            name_parts=name.split('.')
+            return '{}_{}_{}.{}'.format(random.randint(1000,1000000),name_parts[0],random.randint(1000,1000000),name_parts[1])
+        return name
 
     @staticmethod
-    def save_file(f,path=""):
+    def save_file(f,path="",random_ids=True,allowed_extensions=['png','jpg','jpeg','gif','pdf'],allowed_mimetypes=["application/pdf","application/x-pdf","image/png","image/jpg","image/jpeg"]):
+        if FILE_UPLOAD.check_file(f,allowed_extensions=allowed_extensions,allowed_mimetypes=allowed_mimetypes)==False:
+            return None
         os.makedirs(path, exist_ok=True)
-        file_path=path+FILE_UPLOAD.secure_filename(f) if (path[-1]=="/" or path[-1]=="\\") else (path+'/'+FILE_UPLOAD.secure_filename(f) if sys.platform.startswith('win')==False else path+'\\'+FILE_UPLOAD.secure_filename(f))
+        file_path=path+FILE_UPLOAD.secure_filename(f,random_ids=random_ids) if (path[-1]=="/" or path[-1]=="\\") else (path+'/'+FILE_UPLOAD.secure_filename(f,random_ids=random_ids) if sys.platform.startswith('win')==False else path+'\\'+FILE_UPLOAD.secure_filename(f,random_ids=random_ids))    
         f.save(file_path)
         return file_path
 
